IncodesPaymentServices class

Constructors

IncodesPaymentServices()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

cashFreePayment({required BuildContext context, required String clientId, required String clientSecret, required double amount, required String customerName, required String customerEmail, required String customerPhone, String currency = "INR", String paymentGatewayName = "Cashfree", bool testMode = false, dynamic onShowToast()?, dynamic onPaymentSuccess()?, dynamic onPaymentFailure()?}) Future<void>
CashFree Payment
flutterWavePayment({required BuildContext context, required String publicKey, required String customerName, required String customerEmail, required String amount, String currency = "NGN", String? callbackUrl, String paymentGatewayName = "Flutterwave", bool testMode = false, dynamic onShowToast()?, dynamic onPaymentSuccess()?, dynamic onPaymentFailure()?}) Future<void>
FlutterWave Payment
inAppPurchasePayment({required String userId, required List<String> productIds, required double amount, String paymentType = "In App Purchase", dynamic onShowToast()?, dynamic onPaymentSuccess()?, dynamic onPaymentFailure()?}) Future<void>
In-App Purchase Payment
initialize({String? nowPaymentsApiKey, bool isTestMode = false}) → void
Initialize the package configurations.
nowPaymentsCreateInvoice({required String apiKey, required double priceAmount, required String priceCurrency, required String payCurrency, String? orderId, String? orderDescription, String? successUrl, String? cancelUrl, bool isTestMode = false}) Future<NPInvoiceResponse>
NOWPayments: Create Invoice (Generates a Hosted Checkout URL)
nowPaymentsCreatePayment({required String apiKey, required double priceAmount, required String priceCurrency, required String payCurrency, double? payAmount, String? ipnCallbackUrl, String? orderId, String? orderDescription, String? testCase, bool isTestMode = false}) Future<NPCreatePaymentResponse>
NOWPayments: Create Payment
nowPaymentsGetCurrencies({bool fixedRate = false}) Future<NPCurrenciesResponse>
NOWPayments: Get Available Currencies
nowPaymentsGetEstimate({required double amount, required String currencyFrom, required String currencyTo}) Future<NPEstimateResponse>
NOWPayments: Get Estimated Price
nowPaymentsGetMinimumPaymentAmount({required String currencyFrom, required String currencyTo}) Future<NPMinAmountResponse>
NOWPayments: Get Minimum Payment Amount
nowPaymentsGetPaymentStatus(String paymentId) Future<NPPaymentStatusResponse>
NOWPayments: Get Payment Status
paypalPayment({required BuildContext context, required String clientId, required String secretKey, required List<Map<String, dynamic>> transactions, bool testMode = false, String? note, String paymentGatewayName = "PayPal", dynamic onShowToast()?, dynamic onPaymentSuccess()?, dynamic onPaymentFailure()?, dynamic onPaymentCancel()?}) Future<void>
PayPal Payment
payStackPayment({required BuildContext context, required String secretKey, required String customerEmail, required int amount, String currency = "NGN", String? callbackUrl, String paymentGatewayName = "Paystack", bool testMode = false, dynamic onShowToast()?, dynamic onPaymentSuccess()?, dynamic onPaymentFailure()?}) Future<void>
PayStack Payment
razorPayPayment({required String contactNumber, required String emailId, required String razorpayKey, required double amount, required String appName, String? description, String? colorCode, required String currency, String paymentGatewayName = "Razorpay", bool testMode = false, dynamic onShowToast()?, dynamic onPaymentSuccess()?, dynamic onPaymentFailure()?, dynamic onExternalWallet()?}) → dynamic
Razorpay Payment
stripePayment({required int amount, required String currency, required String secretKey, required String publishableKey, required String merchantCountryCode, required String merchantDisplayName, String paymentGatewayName = "Stripe", String? description, dynamic onShowToast()?, dynamic onPaymentSuccess()?, dynamic onPaymentFailure()?, bool isTest = true}) Future<void>
Stripe Payment