Services class

Constructors

Services()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

callCashFressService(BuildContext context) → Future
callFlutterwaveService(BuildContext context) → Future
callInAppPurchaseService(BuildContext context) → Future
callNowPaymentsService(BuildContext context) → Future
callPaypalService(BuildContext context) → Future
callPayStackService(BuildContext context) → Future
callRazorPayService() → Future
callStripeService() → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited